@@ -35,6 +35,8 @@ module PKD
   , module Tgraph.Relabelling
     -- * Smart drawing of Tgraphs and other extras 
   , module Tgraph.Extras
+    -- * Converting to P3 (rhombus) tilings and drawing
+  , module TileLibP3
 
   ) where
 
@@ -45,4 +47,5 @@ import Tgraph.Compose
 import Tgraph.Relabelling
 import Tgraph.Force
 import Tgraph.Extras
+import TileLibP3
 
